@@ -15,6 +15,8 @@ from geonames import Geonames
 from mapquest import Mapquest
 from geocoder import Geocoder
 from elevation import Elevation
+from canadapost import Canadapost
+
 
 def google(location, short_name=True, timeout=5.0, proxies='', client='', secret='', api_key=''):
     """
@@ -70,7 +72,7 @@ def ip(location, proxies='', timeout=5.0):
 
 def elevation(latlng, proxies='', timeout=5.0):
     """
-    Elevation tool will return the Mean Sea Level in meters based
+    Elevation tool will return the Mean elevation above Sea Level in meters based
     on Lat & Lng inputs or an address using Google's elevation API.
 
         >>> latlng = (37.4192, -122.0574)
@@ -111,6 +113,28 @@ def reverse(latlng, short_name=True, proxies='', timeout=5.0):
 
 
 
+def canadapost(location, country='CA', api_key=canadapost_key, proxies='', timeout=5.0):
+    """
+    Retrieves geocoding data from Canada Post's data using Address Complete API.
+
+        >>> g = geocoder.canadapost('453 Booth Street, Ottawa ON')
+        >>> g.postal
+        'K1R 7K9'
+        ...
+
+    USA address simply add the country field to the search request.
+        >>> g = geocoder.canadapost('843 Burg St, Granville, OH', country='USA')
+        >>> g.postal
+        '43023-1079'
+        ...
+
+    Official Docs
+    -------------
+    https://www.canadapost.ca/pca
+    """
+    provider = Canadapost(location, country=country, api_key=api_key)
+    return Geocoder(provider, proxies=proxies, timeout=timeout)
+
 def osm(location, proxies='', timeout=5.0):
     """
     Retrieves geocoding data from OSM's data using Nominatim's geocoding API.
