@@ -9,8 +9,8 @@ class Base(object):
     headers = None
     params = None
     bbox = None
-    x = None
-    y = None
+    x, y = 0.0, 0.0
+    lat, lng = 0.0, 0.0
     west = None
     north = None
     south = None
@@ -37,6 +37,9 @@ class Base(object):
     short_name = None
     elevation = None
     resolution = None
+    isp = None
+    feet = None
+    meters = None
 
     def __init__(self):
         self.json = dict()
@@ -49,6 +52,12 @@ class Base(object):
         # DICTIONARY
         if isinstance(json, dict):
             for keys, values in json.items():
+                # Canada Post
+                if keys == 'Items':
+                    for key, value in values[0].items():
+                        if value:
+                            self.json[key] = value
+
                 # MAXMIND
                 if 'geoname_id' in json:
                     names = json.get('names')
