@@ -5,7 +5,6 @@ from base import Base
 from google import Google
 from location import Location
 
-
 class Elevation(Google, Base):
     name = 'Elevation Google'
     url = 'http://maps.googleapis.com/maps/api/elevation/json'
@@ -20,13 +19,21 @@ class Elevation(Google, Base):
         # Parameters for URL request
         self.params['locations'] = self.latlng
 
+    @property
+    def meters(self):
+        return round(self.elevation, 1)
+
+    @property
+    def feet(self):
+        return round(self.elevation * 3.28084, 1)
+
     @property
     def elevation(self):
         return self.safe_format('results-elevation')
 
     @property
     def resolution(self):
-        return self.safe_format('results-resolution')
+        return round(self.safe_format('results-resolution'), 1)
 
 if __name__ == '__main__':
     from api import Geocoder
