@@ -151,19 +151,21 @@ class Geocoder(object):
 
         # IP Address
         self.ip = self.provider.ip
+        self.isp = self.provider.isp
 
         # Geom for PostGIS
-        self.geom = "ST_GeomFromText('POINT({0} {1})', 4326)".format(self.lng, self.lat)
+        self.geom = "POINT({0} {1})".format(self.lng, self.lat)
 
         # Build Elevation
         self.elevation = self.provider.elevation
         self.resolution = self.provider.resolution
+        self.feet = self.provider.feet
+        self.meters = self.provider.meters
 
         # Build JSON
         self.json = self._build_json()
         self.geojson = self._build_geojson()
 
-
     def _build_json(self):
         json = dict()
         json['provider'] = self.name
@@ -183,6 +185,9 @@ class Geocoder(object):
             json['lng'] = self.x
             json['lat'] = self.y
 
+        if self.isp:
+            json['isp'] = self.isp
+
         if self.bbox:
             json['bbox'] = self.bbox
 
@@ -217,9 +222,9 @@ class Geocoder(object):
             json['ip'] = self.ip
 
         if self.elevation:
-            json['elevation'] = self.elevation
+            json['meters'] = self.meters
             json['resolution'] = self.resolution
-            self.address = self.elevation
+            self.address = self.meters + 'm'
 
         return json
 
