@@ -49,18 +49,23 @@ class Google(Base):
         encodedSignature = base64.urlsafe_b64encode(signature.digest())
         return encodedSignature
 
+    @property
     def lat(self):
         return self.safe_coord('location-lat')
 
+    @property
     def lng(self):
         return self.safe_coord('location-lng')
 
+    @property
     def status(self):
         return self.safe_format('status')
 
+    @property
     def quality(self):
         return self.safe_format('geometry-location_type')
 
+    @property
     def bbox(self):
         south = self.json.get('southwest-lat')
         west = self.json.get('southwest-lng')
@@ -68,63 +73,73 @@ class Google(Base):
         east = self.json.get('northeast-lng')
         return self.safe_bbox(south, west, north, east)
 
+    @property
     def address(self):
         return self.safe_format('results-formatted_address')
 
+    @property
     def postal(self):
         if self.short_name:
             return self.safe_format('postal_code')
         else:
             return self.safe_format('postal_code-long_name')
 
+    @property
     def street_number(self):
         if self.short_name:
             return self.safe_format('street_number')
         else:
             return self.safe_format('street_number-long_name')
 
+    @property
     def route(self):
         if self.short_name:
             return self.safe_format('route')
         else:
             return self.safe_format('route-long_name')
 
+    @property
     def neighborhood(self):
         if self.short_name:
             return self.safe_format('neighborhood')
         else:
             return self.safe_format('neighborhood-long_name')
 
+    @property
     def sublocality(self):
         if self.short_name:
             return self.safe_format('sublocality')
         else:
             return self.safe_format('sublocality-long_name')
 
+    @property
     def locality(self):
         if self.short_name:
             return self.safe_format('locality')
         else:
             return self.safe_format('locality-long_name')
 
-    def division(self):
+    @property
+    def county(self):
         if self.short_name:
             return self.safe_format('administrative_area_level_2')
         else:
             return self.safe_format('administrative_area_level_2-long_name')
 
+    @property
     def state(self):
         if self.short_name:
             return self.safe_format('administrative_area_level_1')
         else:
             return self.safe_format('administrative_area_level_1-long_name')
 
+    @property
     def country(self):
         if self.short_name:
             return self.safe_format('country')
         else:
             return self.safe_format('country-long_name')
 
-
 if __name__ == '__main__':
-    pass
+    g = Google("Orleans, Ottawa")
+    print g.url
\ No newline at end of file
