@@ -5,12 +5,16 @@ import geocoder
 import pytest
 import unittest
 
+address = '453 Booth Street, Ottawa'
 location = 'Ottawa, ON, Canada'
 ip = '74.125.226.99'
 repeat = 3
 ottawa = (45.4215296, -75.6971930)
 toronto = (43.653226, -79.3831843)
 
+g = geocoder.canadapost(address)
+print g
+
 def test_entry_points():
     geocoder.ip
     geocoder.get
@@ -23,8 +27,13 @@ def test_entry_points():
     geocoder.reverse
     geocoder.geonames
     geocoder.mapquest
+    geocoder.canadapost
     geocoder.population
 
+def test_canadapost():
+    g = geocoder.google(address)
+    assert g.ok
+
 def test_google():
     g = geocoder.google(location)
     assert g.ok
